OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Falsches Passwort",
    "The new password can not be the same as the previous one" : "Das neue Passwort kann nicht das gleiche Passwort wie das vorherige sein",
    "No user supplied" : "Keinen Benutzer angegeben",
    "Authentication error" : "Authentifizierungsfehler",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Bitte geben Sie ein Wiederherstellungspasswort für das Administratorkonto an, da sonst alle Benutzerdaten verloren gehen können.",
    "Wrong admin recovery password. Please check the password and try again." : "Falsches Wiederherstellungspasswort für das Admin-Konto. Bitte überprüfen Sie das Passwort und versuchen Sie es erneut.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Das Backend unterstützt die Passwortänderung nicht, aber der Benutzerschlüssel wurde erfolgreich aktualisiert.",
    "Unable to change password" : "Passwort konnte nicht geändert werden",
    "%s password changed successfully" : "%s Passwort erfolgreich geändert",
    "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktieren Sie Ihren Administrator.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
    "Federated Cloud Sharing" : "Federated-Cloud-Sharing",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL verwendet eine veraltete %s Version (%s). Bitte aktualisieren Sie ihr Betriebssystem, da ansonsten Funktionen, wie z.B. %s, nicht zuverlässig funktionieren werden.",
    "A problem occurred, please check your log files (Error: %s)" : "Es ist ein Problem aufgetreten, bitte überprüfen Sie Ihre Logdateien (Fehler: %s)",
    "Migration Completed" : "Migration abgeschlossen",
    "Group already exists." : "Gruppe existiert bereits.",
    "Unable to add group." : "Gruppe konnte nicht angelegt werden.",
    "Unable to delete group." : "Gruppe konnte nicht gelöscht werden.",
    "log-level out of allowed range" : "Log-Level außerhalb des erlaubten Bereichs",
    "Saved" : "Gespeichert",
    "test email settings" : "E-Mail-Einstellungen testen",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Beim Senden der E-Mail ist ein Problem aufgetreten. Bitte überprüfen Sie Ihre Einstellungen. (Fehler: %s)",
    "Email sent" : "E-Mail gesendet",
    "You need to set your user email before being able to send test emails." : "Sie müssen Ihre Benutzer-E-Mail-Adresse einstellen, bevor Sie Test-E-Mails versenden können.",
    "Couldn't change the email address because the user does not exist" : "Die E-Mail Adresse konnte nicht geändert werden, da der Benutzer nicht existiert",
    "Couldn't change the email address because the token is invalid" : "Die E-Mail Adresse konnte nicht geändert werden, da der Token ungültig ist",
    "Invalid mail address" : "Ungültige E-Mail-Adresse",
    "A user with that name already exists." : "Ein Benutzer mit diesem Namen existiert bereits.",
    "Unable to create user." : "Benutzer konnte nicht erstellt werden.",
    "Your %s account was created" : "Ihr %s-Konto wurde erstellt",
    "Unable to delete user." : "Benutzer konnte nicht gelöscht werden.",
    "Forbidden" : "Verboten",
    "Invalid user" : "Ungültiger Benutzer",
    "Unable to change mail address" : "E-Mail-Adresse konnte nicht geändert werden",
    "Email has been changed successfully." : "E-Mail Adresse wurde erfolgreich geändert.",
    "An email has been sent to this address for confirmation" : "Eine E-Mail wurde zur Bestätigung an diese Adresse gesendet",
    "No email was sent because you already sent one recently. Please try again later." : "Es wurde keine E-Mail versendet, da bereits eine E-Mail versendet wurde. Bitte später noch einmal versuchen.",
    "Your full name has been changed." : "Ihr vollständiger Name ist geändert worden.",
    "Unable to change full name" : "Der vollständige Name konnte nicht geändert werden",
    "%s email address confirm" : "%s E-Mail Adressbestätigung",
    "Couldn't send email address change confirmation mail. Please contact your administrator." : "Die Bestätigung zur Änderung der E-Mail Adresse konnte nicht versendet werden. Bitte kontaktieren Sie Ihren Administrator.",
    "%s email address changed successfully" : "%s E-Mail Adresse wurde erfolgreich geändert",
    "Couldn't send email address change notification mail. Please contact your administrator." : "Die Benachrichtigung zur Änderung der E-Mail Adresse konnte nicht versendet werden. Bitte kontaktieren Sie Ihren Administrator.",
    "Unable to enable/disable user." : "Benutzer konnte nicht de-/aktiviert werden.",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "__language_name__" : "Deutsch (Förmlich: Sie)",
    "Language changed" : "Sprache geändert",
    "Invalid request" : "Ungültige Anforderung",
    "Admins can't remove themself from the admin group" : "Administratoren können sich nicht selbst aus der admin-Gruppe löschen",
    "Unknown user" : "Unbekannter Benutzer",
    "Couldn't remove app." : "Die App konnte nicht entfernt werden.",
    "Official" : "Offiziell",
    "Approved" : "Geprüft",
    "All" : "Alle",
    "Enabled" : "Aktiviert",
    "Not enabled" : "Nicht aktiviert",
    "No apps found for your version" : "Es wurden keine Apps für Ihre Version gefunden",
    "The app will be downloaded from the app store" : "Die App wird aus dem App-Store heruntergeladen",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Offizielle Apps werden von und innerhalb der ownCloud-Community entwickelt. Sie stellen zentrale Funktionen von ownCloud bereit und sind auf den Produktiveinsatz vorbereitet.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Geprüfte Apps werden von vertrauenswürdigen Entwicklern entwickelt und haben eine oberflächliche Sicherheitsprüfung durchlaufen. Sie werden innerhalb eines offenen Code-Repositorys aktiv gepflegt und ihre Betreuer erachten sie als stabil genug für für den gelegentlichen bis normalen Einsatz.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Diese App ist nicht auf Sicherheitsprobleme hin überprüft und ist neu oder bekanntermaßen instabil. Die Installation erfolgt auf eigenes Risiko.",
    "Please wait...." : "Bitte warten…",
    "Error while disabling app" : "Beim Deaktivieren der App ist ein Fehler aufgetreten",
    "Disable" : "Deaktivieren",
    "Enable" : "Aktivieren",
    "Error while enabling app" : "Beim Aktivieren der App ist ein Fehler aufgetreten",
    "Error: this app cannot be enabled because it makes the server unstable" : "Fehler: Diese App kann nicht aktiviert werden, da es den Server instabil macht.",
    "Error: could not disable broken app" : "Fehler: Die beschädigte Anwendung konnte nicht deaktiviert werden",
    "Error while disabling broken app" : "Beim Deaktivieren der defekten App ist ein Fehler aufgetreten",
    "Updating...." : "Update…",
    "Error while updating app" : "Es ist ein Fehler während des Updates aufgetreten",
    "Updated" : "Aktualisiert",
    "Uninstalling ...." : "Wird deinstalliert…",
    "Error while uninstalling app" : "Fehler beim Deinstallieren der App",
    "Uninstall" : "Deinstallieren",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Die App wurde aktiviert, aber sie benötigt ein Update. Sie werden zur Update Seite in 5 Sekunden weitergeleitet.",
    "App update" : "App aktualisieren",
    "Experimental" : "Experimentell",
    "No apps found for {query}" : "Keine Applikationen für {query} gefunden",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Sind Sie sich wirklich sicher, dass Sie »{domain}« als vertrauenswürdige Domain hinzufügen möchten?",
    "Add trusted domain" : "Vertrauenswürdige Domain hinzufügen",
    "Migration in progress. Please wait until the migration is finished" : "Migration in Arbeit. Bitte warten Sie, bis die Migration beendet ist",
    "Migration started …" : "Migration begonnen…",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Es ist ein Fehler aufgetreten. Bitte laden Sie ein ASCII-kodiertes PEM-Zertifikat hoch.",
    "Valid until {date}" : "Gültig bis {date}",
    "Delete" : "Löschen",
    "Disconnect" : "Trennen",
    "Error while loading browser sessions and device tokens" : "Fehler beim Laden der Browser-Sitzungen und Gerätetoken",
    "Error while creating device token" : "Fehler beim Erstellen des Gerätetokens",
    "Error while deleting the token" : "Fehler beim Löschen des Gerätetokens",
    "Sending..." : "Wird gesendet…",
    "Failed to change the email address." : "Fehler beim Ändern der E-Mail-Adresse.",
    "Email changed successfully." : "E-Mail Adresse erfolgreich geändert.",
    "An error occurred: {message}" : "Ein Fehler ist aufgetreten: {message}",
    "Select a profile picture" : "Wählen Sie ein Profilbild",
    "Very weak password" : "Sehr schwaches Passwort",
    "Weak password" : "Schwaches Passwort",
    "So-so password" : "Passables Passwort",
    "Good password" : "Gutes Passwort",
    "Strong password" : "Starkes Passwort",
    "Groups" : "Gruppen",
    "Unable to delete {objName}" : "Löschen von {objName} nicht möglich",
    "Error creating group: {message}" : "Fehler beim Erstellen einer Gruppe: {message}",
    "A valid group name must be provided" : "Ein gültiger Gruppenname muss angegeben werden",
    "deleted {groupName}" : "{groupName} gelöscht",
    "undo" : "rückgängig machen",
    "never" : "niemals",
    "deleted {userName}" : "{userName} gelöscht",
    "add group" : "Gruppe hinzufügen",
    "Invalid quota value \"{val}\"" : "Ungültiger Wert \"{val}\" für das Kontigent",
    "enabled" : "aktiviert",
    "disabled" : "deaktiviert",
    "User {uid} has been {state}!" : "Benutzer {uid} wurde {state}!",
    "no group" : "Keine Gruppe",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Die Änderung des Passworts führt zu Datenverlust, weil die Datenwiederherstellung für diesen Benutzer nicht verfügbar ist",
    "Password successfully changed" : "Passwort wurde erfolgreich geändert",
    "A valid username must be provided" : "Es muss ein gültiger Benutzername angegeben werden",
    "Error creating user: {message}" : "Fehler beim Erstellen eines Benutzers: {message}",
    "A valid password must be provided" : "Es muss ein gültiges Passwort angegeben werden",
    "A valid email must be provided" : "Es muss eine gültige E-Mail-Adresse angegeben werden",
    "Use the following link to confirm your changes to the email address: {link}" : "Benutzen Sie den folgenden Link, um die Änderung der E-Mail Adresse zu bestätigen: {link}",
    "Email address changed to {mailAddress} successfully." : "E-Mail Adresse wurde erfolgreich auf {mailAddress} geändert.",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Hallo,<br><br>hier nur kurz die Mitteilung, dass Sie jetzt ein %s-Konto haben.<br><br>Ihr Benutzername: %s<br>Greifen Sie darauf zu: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Noch einen schönen Tag!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Hallo,\n\nhier nur kurz die Mitteilung, dass Sie jetzt ein %s-Konto haben.\n\nIhr Benutzername: %s\nGreifen Sie darauf zu: %s\n\n",
    "User documentation" : "Dokumentation für Benutzer",
    "Administrator documentation" : "Dokumentation für Administratoren",
    "Online documentation" : "Online-Dokumentation",
    "Forum" : "Forum",
    "Issue tracker" : "Issue Tracker",
    "Commercial support" : "Kommerzieller Support",
    "Apps Management" : "Verwaltung der Apps",
    "Developer documentation" : "Dokumentation für Entwickler",
    "by %s" : "durch %s",
    "%s-licensed" : "%s-Lizensiert",
    "Documentation:" : "Dokumentation:",
    "Admin documentation" : "Dokumentation für Administratoren",
    "Visit website" : "Webseite besuchen",
    "Report a bug" : "Melden Sie einen technischen Fehler",
    "Show description …" : "Beschreibung anzeigen…",
    "Hide description …" : "Beschreibung ausblenden…",
    "This app has no minimum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Dieser App ist keine minimum ownCloud Version zugewiesen. Dies wird ein Fehler in ownCloud 11 und später sein.",
    "This app has no maximum ownCloud version assigned. This will be an error in ownCloud 11 and later." : "Diese App hat keine maximale ownCloud Version zugeordnet. Dies wird ein Fehler in ownCloud 11 und später sein.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Diese App kann nicht installiert werden, weil die folgenden Abhängigkeiten nicht erfüllt sind:",
    "Enable only for specific groups" : "Nur für bestimmte Gruppen aktivieren",
    "Uninstall App" : "App deinstallieren",
    "Show enabled apps" : "Aktivierte Apps anzeigen",
    "Show disabled apps" : "Deaktivierte Apps anzeigen",
    "Cron" : "Cron",
    "Last cron job execution: %s." : "Letzte Cron-Job-Ausführung: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Letzte Cron-Job-Ausführung: %s. Möglicherweise liegt ein Fehler vor.",
    "Cron was not executed yet!" : "Cron wurde bis jetzt noch nicht ausgeführt!",
    "Open documentation" : "Dokumentation öffnen",
    "Execute one task with each page loaded" : "Eine Aufgabe bei jedem Laden der Seite ausführen",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php ist als Webcron-Dienst registriert, der die cron.php alle 15 Minuten per HTTP aufruft.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Benutzen Sie den systemeigenen Cron-Dienst, um die cron.php alle 15 Minuten aufzurufen.",
    "SSL Root Certificates" : "SSL Root Zertifikate",
    "Common Name" : "Common Name",
    "Valid until" : "Gültig bis",
    "Issued By" : "Ausgestellt von:",
    "Valid until %s" : "Gültig bis %s",
    "Import root certificate" : "Root-Zertifikat importieren",
    "Server-side encryption" : "Serverseitige Verschlüsselung",
    "Enable server-side encryption" : "Serverseitige Verschlüsselung aktivieren",
    "Please read carefully before activating server-side encryption: " : "Bitte lesen Sie ganz genau, bevor Sie die Serverseite Verschlüsselung aktivieren:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Wird die Verschlüsselung einmal aktiviert, so werden alle ab diesem Zeitpunkt hochgeladene Dateien verschlüsselt. Sie kann nur wieder deaktiviert werden, wenn das Verschlüsselungsmodul dies unterstützt und alle Voraussetzungen (wie das Setzen eines Wiederherstellungsschlüssels) im Vorhinein erfüllt wurden.",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Verschlüsselung an sich garantiert nicht die Sicherheit des Systems. Bitte schauen Sie in die ownCloud Dokumentation für weitere Informationen wie die Verschlüsselungs-App funktioniert und welche Anwendungsfälle unterstützt werden.",
    "Be aware that encryption always increases the file size." : "Bedenke das durch die Verschlüsselung die Dateigröße zunimmt. ",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Es ist immer gut, regelmäßig Sicherungskopien von ihren Daten zu machen. Falls Sie die Verschlüsselung nutzen, sollten Sie auch eine Sicherung der Verschlüsselungsschlüssel zusammen mit ihren Daten machen.",
    "This is the final warning: Do you really want to enable encryption?" : "Dies ist die letzte Warnung: Wollen Sie die Verschlüsselung wirklich aktivieren?",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Kein Verschlüsselungs-Modul geladen, bitte aktiviere ein Verschlüsselungs-Modul im Anwendungs-Menü.",
    "Select default encryption module:" : "Standard-Verschlüsselungs-Modul auswählen:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Sie müssen Ihre Verschlüsselungsschlüssel von der alten Verschlüsselung (ownCloud <= 8.0) zur Neuen migrieren. Bitte aktivieren Sie das \"Default Encryption Module\" und rufen Sie 'occ encryption:migrate' auf.",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Sie müssen Ihre Verschlüsselungsschlüssel von der alten Verschlüsselung (ownCloud <= 8.0) zur Neuen migrieren.",
    "Start migration" : "Migration beginnen",
    "Sharing" : "Teilen",
    "Allow apps to use the Share API" : "Apps die Benutzung der Share-API erlauben",
    "Allow users to share via link" : "Benutzern erlauben, Inhalte über Links zu teilen",
    "Allow public uploads" : "Öffentliches Hochladen erlauben",
    "Enforce password protection" : "Passwortschutz erzwingen",
    "Set default expiration date" : "Standardmäßiges Ablaufdatum setzen",
    "Allow users to send mail notification for shared files" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien zu senden",
    "Allow users to share file via social media" : "Benutzern erlauben, Inhalte über die sozialen Medien zu teilen",
    "Expire after " : "Ablauf nach ",
    "days" : "Tagen",
    "Enforce expiration date" : "Ablaufdatum erzwingen",
    "Allow resharing" : "Weiterverteilen erlauben",
    "Allow sharing with groups" : "Das Teilen mit Gruppen erlauben",
    "Restrict users to only share with users in their groups" : "Benutzer auf das Teilen innerhalb ihrer Gruppen beschränken",
    "Allow users to send mail notification for shared files to other users" : "Benutzern erlauben, E-Mail-Benachrichtigungen für freigegebene Dateien an andere Benutzer zu senden",
    "Exclude groups from sharing" : "Gruppen von Freigaben ausschließen",
    "These groups will still be able to receive shares, but not to initiate them." : "Diese Gruppen können weiterhin Freigaben empfangen, aber selbst keine mehr initiieren.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Die Auto-Vervollständigung von Benutzernamen im Teilen-Dialog erlauben. Wenn dies deaktiviert ist, muss der vollständige Benutzername eingegeben werden.",
    "Restrict enumeration to group members" : "Aufzählung auf Gruppenmitglieder beschränken",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Alles (fatale Probleme, Fehler, Warnungen, Infos, Fehlerdiagnose)",
    "Info, warnings, errors and fatal issues" : "Infos, Warnungen, Fehler und fatale Probleme",
    "Warnings, errors and fatal issues" : "Warnungen, Fehler und fatale Probleme",
    "Errors and fatal issues" : "Fehler und fatale Probleme",
    "Fatal issues only" : "Nur kritische Fehler",
    "Log" : "Log",
    "What to log" : "Was geloggt wird",
    "Download logfile (%s)" : "Logdatei (%s) herunterladen",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Die Logdatei ist größer als 100 MB. Es kann etwas Zeit beanspruchen, sie herunterzuladen!",
    "None" : "Keine",
    "Login" : "Anmelden",
    "Plain" : "Plain",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-Mail-Server",
    "This is used for sending out notifications." : "Dies wird für das Senden von Benachrichtigungen verwendet.",
    "Send mode" : "Sendemodus",
    "Encryption" : "Verschlüsselung",
    "From address" : "Absenderadresse",
    "mail" : "Mail",
    "Authentication method" : "Authentifizierungsmethode",
    "Authentication required" : "Authentifizierung benötigt",
    "Server address" : "Serveradresse",
    "Port" : "Port",
    "Credentials" : "Zugangsdaten",
    "SMTP Username" : "SMTP Benutzername",
    "SMTP Password" : "SMTP Passwort",
    "Store credentials" : "Anmeldeinformationen speichern",
    "Test email settings" : "E-Mail-Einstellungen testen",
    "Send email" : "E-Mail senden",
    "Security & setup warnings" : "Sicherheits- & Einrichtungswarnungen",
    "php does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP scheint zur Abfrage von Systemumgebungsvariablen nicht richtig eingerichtet zu sein. Der Test mit getenv (\"PATH\") liefert nur eine leere Antwort zurück.",
    "Please check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation documentation ↗</a> for php configuration notes and the php configuration of your server, especially when using php-fpm." : "Bitte schauen Sie in der <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Installationsdokumentation ↗</a>auf Hinweise zur PHP-Konfiguration, sowie die PHP-Konfiguration ihres Servers, insbesondere dann, wenn Sie PHP-FPM einsetzten.",
    "The Read-Only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Die schreibgeschützte Konfiguration wurde aktiviert. Dies verhindert das Setzen einiger Einstellungen über die Web-Schnittstelle. Weiterhin muss bei jedem Update der Schreibzugriff auf die Datei händisch aktiviert werden.",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP ist offenbar so konfiguriert, dass PHPDoc-Blöcke in der Anweisung entfernt werden. Dadurch sind mehrere Kern-Apps nicht erreichbar.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dies wird wahrscheinlich durch Zwischenspeicher/Beschleuniger wie etwa Zend OPcache oder eAccelerator verursacht.",
    "Your database does not run with \"READ COMMITED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "ihre Datenbank läuft nicht mit der \"READ COMMITED\" Transaktionsisolationsstufe. Dies kann Probleme hervorrufen, wenn mehrere Aktionen parallel ausgeführt werden.",
    "%1$s below version %2$s is installed, for stability and performance reasons we recommend updating to a newer %1$s version." : "%1$s ist in einer älteren Version als %2$s installiert. Aus Stabilitäts- und Performancegründen empfehlen wir eine Aktualisierung auf eine neuere %1$s-Version",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "Das PHP-Modul 'fileinfo' fehlt. Wir empfehlen Ihnen dieses Modul zu aktivieren, um die besten Resultate bei der Bestimmung der Dateitypen zu erzielen.",
    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable 'filelocking.enabled' in config.php to avoid these problems. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transaktionales Sperren ist deaktiviert, was zu Problemen mit Laufzeitbedingungen führen kann. Aktivieren Sie 'filelocking.enabled' in der config.php  diese Probleme zu vermeiden. Weitere Informationen findest Sie in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation ↗</a>.",
    "Transactional file locking should be configured to use memory-based locking, not the default slow database-based locking. See the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a> for more information." : "Transaktionales Sperren sollte zur Nutzung des speicherbasierten Sperrens anstatt des langsamen Datenbank basierten Sperrens konfiguriert werden. Weitere Informationen findest Sie in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation ↗</a>.",
    "System locale can not be set to a one which supports UTF-8." : "Es kann kein Systemgebietsschema gesetzt werden, das UTF-8 unterstützt.",
    "This means that there might be problems with certain characters in file names." : "Dies bedeutet, dass es zu Problemen mit bestimmten Zeichen in Dateinamen kommen kann.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Wir empfehlen dringend, die erforderlichen Pakete auf Ihrem System zu installieren, damit eines der folgenden Gebietsschemata unterstützt wird: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Wenn sich Ihre Installation nicht im Wurzelverzeichnis der Domain befindet und Cron aus dem System genutzt wird, kann es zu Fehlern bei der URL-Generierung kommen. Um dies zu verhindern, setzen Sie bitte die „overwrite.cli.url“-Option in Ihrer config.php auf das Web-Wurzelverzeichnis Ihrer Installation (Vorschlag: „%s“).",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite wird als Datenbank verwendet. Bei größeren Installationen wird empfohlen, auf ein anderes Datenbank-Backend zu wechseln.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Insbesondere bei der Nutzung des Desktop Clients zur Dateisynchronisierung wird vom Einsatz von SQLite abgeraten.",
    "To migrate to another database use the command line tool: 'occ db:convert-type', or see the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation ↗</a>." : "Um zu einer anderen Datenbank zu migrieren, benutzen Sie bitte die Kommandozeile: 'occ db:convert-type', oder in die <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation ↗</a> schauen.",
    "We recommend to enable system cron as any other cron method has possible performance and reliability implications." : "Wir empfehlen das Aktivieren des System-Cron da jede andere Cron-Methode Auswirkungen auf die Leistungsfähigkeit und die Zuverlässigkeit hat.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Die Ausführung des Cron-Jobs über die Kommandozeile war nicht möglich. Die folgenden technischen Fehler sind dabei aufgetreten:",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"#log-section\">log</a>." : "Bitte überprüfen Sie noch einmal die <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Installationsanleitungen ↗</a> und kontrollieren Sie das <a href=\"#log-section\">Log</a> auf mögliche Fehler oder Warnungen.",
    "All checks passed." : "Alle Checks bestanden.",
    "System Status" : "Systemstatus",
    "Tips & tricks" : "Tipps & Tricks",
    "How to do backups" : "Wie man Backups anlegt",
    "Advanced monitoring" : "Erweitertes Monitoring",
    "Performance tuning" : "Leistungsoptimierung",
    "Improving the config.php" : "Die config.php optimieren",
    "Theming" : "Themes verwenden",
    "Hardening and security guidance" : "Systemhärtung und Sicherheitsempfehlungen",
    "Get the apps to sync your files" : "Installieren Sie die Anwendungen, um Ihre Dateien zu synchronisieren",
    "Desktop client" : "Desktop-Client",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "If you want to support the project\n\t\t\t<a href=\"https://owncloud.org/contribute\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">join development</a>\n\t\t\tor\n\t\t\t<a href=\"https://owncloud.org/promote\"\n\t\t\ttarget=\"_blank\" rel=\"noreferrer\">spread the word</a>!" : "Wenn Sie das Projekt unterstützen möchten,\n<a href=\"https://owncloud.org/contribute\"\ntarget=\"_blank\" rel=\"noreferrer\">beteiligen Sie sich an der Entwicklung</a>\noder\n<a href=\"https://owncloud.org/promote\"\ntarget=\"_blank\" rel=\"noreferrer\">helfen Sie mit, es bekannter zu machen</a>!",
    "Show First Run Wizard again" : "Den Einrichtungsassistenten erneut anzeigen",
    "Profile picture" : "Profilbild",
    "Upload new" : "Neues hochladen",
    "Select from Files" : "Aus Dateien wählen",
    "Remove image" : "Bild entfernen",
    "png or jpg, max. 20 MB" : "png oder jpg, max. 20 MB",
    "Picture provided by original account" : "Bild von Original-Konto zur Verfügung gestellt",
    "Cancel" : "Abbrechen",
    "Choose as profile picture" : "Als Profilbild auswählen",
    "Full name" : "Vollständiger Name",
    "No display name set" : "Kein Anzeigename angegeben",
    "Email" : "E-Mail",
    "Your email address" : "Ihre E-Mail-Adresse",
    "Change email" : "E-Mail-Adresse ändern",
    "Set email" : "E-Mail Adresse eingeben",
    "For password recovery and notifications" : "Für Passwort Wiederherstellung und Benachrichtigungen",
    "No email address set" : "Keine E-Mail-Adresse angegeben",
    "You are member of the following groups:" : "Sie sind Mitglied folgender Gruppen:",
    "Password" : "Passwort",
    "Unable to change your password" : "Das Passwort konnte nicht geändert werden",
    "Current password" : "Aktuelles Passwort",
    "New password" : "Neues Passwort",
    "Change password" : "Passwort ändern",
    "Language" : "Sprache",
    "Help translate" : "Helfen Sie bei der Übersetzung",
    "Unlimited" : "Unbegrenzt",
    "You are using %s of %s" : "Sie benutzen %s von %s",
    "You are using %s of %s (%s %%)" : "Sie benutzen %s von %s (%s %%)",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Entwickelt von der {communityopen}ownCloud-Community{linkclose}, der {githubopen}Quellcode{linkclose} ist unter den Bedingungen der {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} lizenziert.",
    "Sessions" : "Sitzungen",
    "These are the web, desktop and mobile clients currently logged in to your ownCloud." : "Dies sind die Web-, Desktop und mobilen Clients, mit denen Sie aktuell in Ihrer ownCloud angemeldet sind.",
    "Browser" : "Browser",
    "Most recent activity" : "Neueste Aktivität",
    "App passwords" : "App-Passwörter",
    "You've linked these apps." : "Sie haben diese Apps verbunden.",
    "Name" : "Name",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Ein App-Passwort ist ein Passwort, dass einer App oder einem Gerät erlaubt auf Ihren %s-Konto zuzugreifen.",
    "App name" : "App-Name",
    "Create new app password" : "Neues App-Passwort erstellen",
    "Use the credentials below to configure your app or device." : "Verwenden Sie die folgenden Zugangsdaten um Ihre App oder Ihr Gerät zu konfigurieren.",
    "Username" : "Benutzername",
    "Done" : "Erledigt",
    "Version" : "Version",
    "Personal" : "Persönlich",
    "Admin" : "Administrator",
    "Error" : "Fehler",
    "No panels for this section." : "Keine Tafeln für diese Auswahl",
    "Show enabled/disabled option" : "Option Aktiviert/Deaktiviert anzeigen",
    "Show storage location" : "Speicherort anzeigen",
    "Show last log in" : "Letzte Anmeldung anzeigen",
    "Show user backend" : "Benutzer-Backend anzeigen",
    "Send email to new user" : "E-Mail an neuen Benutzer senden",
    "Show email address" : "E-Mail Adresse anzeigen",
    "E-Mail" : "E-Mail",
    "Create" : "Erstellen",
    "Admin Recovery Password" : "Admin-Passwort-Wiederherstellung",
    "Enter the recovery password in order to recover the users files during password change" : "Geben Sie das Wiederherstellungspasswort ein, um die Benutzerdateien während der Passwortänderung wiederherzustellen",
    "Add Group" : "Gruppe hinzufügen",
    "Group" : "Gruppe",
    "Everyone" : "Jeder",
    "Admins" : "Administratoren",
    "Default Quota" : "Standardkontingent",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Bitte Speicherkontingent eingeben (z.B.: „512 MB“ oder „12 GB“)",
    "Other" : "Andere",
    "Full Name" : "Vollständiger Name",
    "Group Admin for" : "Gruppenadministrator für",
    "Quota" : "Kontingent",
    "Storage Location" : "Speicherort",
    "User Backend" : "Benutzer-Backend",
    "Last Login" : "Letzte Anmeldung",
    "change full name" : "Vollständigen Namen ändern",
    "set new password" : "Neues Passwort setzen",
    "change email address" : "E-Mail-Adresse ändern",
    "Default" : "Standard",
    "Change" : "Ändern",
    "Share" : "Teilen",
    "installing and updating apps via the market or Federated Cloud Sharing" : "Das Installieren und Aktualisieren von Apps durch den App-Store oder durch Federated Cloud Sharing",
    "White-listed Domains" : "Weiße Liste der Domains",
    "Add Domain" : "Domain hinzufügen",
    "Empty app name is not allowed." : "Ein leerer App-Name ist nicht erlaubt.",
    "CORS" : "KERNE",
    "User ID" : "Benutzer-ID",
    "Email address" : "E-Mail-Adresse",
    "Invalid email address" : "Ungültige E-Mail-Adresse",
    "Extra field to display in autocomplete results" : "Separates Feld zur Anzeige des Autovervollständigen-Ergebnisses",
    "Restrict users to only share with groups they are member of" : "Benutzer auf das Teilen innerhalb der Gruppen, deren Mitglied sie sind, beschränken",
    "Default user and group share permissions" : "Nutzer und Gruppen Standard-Berechtigungen für das Teilen",
    "Enforce password protection for read-only links" : "Passwort-Schutz für \"nur lesen\" Links durchsetzen",
    "Enforce password protection for read & write links" : "Passwort-Schutz für lesbare und schreibbare Links durchsetzen.",
    "Enforce password protection for upload-only (File Drop) links" : "Passwort-Schutz für \"nur hochladen\" Links/Dateien durchsetzen.",
    "No Domains." : "Keine Domains.",
    "Are you sure you want to remove this domain?" : "Sind Sie sicher, dass Sie diese Domain entfernen möchten?",
    "Add" : "Hinzufügen",
    "Domain" : "Domain",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "Die Konfigurationsdatei ist schreibgeschützt. Bitte passen Sie Ihre Einstellungen durch manuelle Bearbeitung der Konfigurationsdatei selbst an.",
    "Email changed successfully for {user}." : "E-Mail erfolgreich für {user} geändert.",
    "You are not a member of any groups." : "Du bist kein Mitglied einer Gruppe.",
    "In a clustered setup please make sure to sync the config.php file across all nodes." : "In einem gruppierten Umgebung stellen Sie bitte sicher, dass die config.php-Datei über alle Knoten synchronisiert wird.",
    "You are using %s" : "Sie verwenden %s",
    "These are the web, desktop and mobile clients currently logged in to your %s." : "Diese Web-, Desktop- und Mobil-Clients sind aktuell an 1%s angemeldet",
    "Automatically accept new incoming local user shares" : "Erhaltene lokale Benutzerfreigaben automatisch akzeptieren",
    "Legal" : "Rechtliches",
    "Imprint URL:" : "Impressum-URL:",
    "Imprint URL" : "Impressum-URL",
    "Privacy Policy URL:" : "Datenschutz-URL:",
    "Privacy Policy URL" : "Datenschutz-URL",
    "App passwords / tokens" : "App-Passwörter / Token",
    "App passwords or tokens are passcodes that give an app or device permissions to access your %s account." : "App-Passwörter oder Token sind passcodes, die einer App oder einem Gerät Zugriff auf Ihr %s-Konto geben.",
    "Use them as a security measure to hide your actual password which you may only want to use for web interface login." : "Benutzen Sie diese als Sicherheitsmaßnahme, um Ihr richtiges Passwort nur für den Webzugriff zu verwenden.",
    "Create new app passcode" : "Neuen App-Passcode erstellen",
    "Password / Token" : "Passwort / Token",
    "Owner language" : "Sprache des Eigentümers",
    "Language used for public mail notifications for shared files" : "Sprache, die für öffentliche Mail-Benachrichtigungen für geteilte Daten benutzt wird "
},
"nplurals=2; plural=(n != 1);");
